@@ -2,12 +2,11 @@
 All configurations for pyscrapers
 """
 import os
+import logging
 
 import browser_cookie3
 from pytconf import Config, ParamCreator
 
-import logging
-
 
 class ConfigLogging(Config):
     """
@@ -69,14 +68,13 @@ class ConfigCookiesSource(Config):
         default="firefox",
     )
 
-    cookies = None
 
-    @classmethod
-    def config_cookies(cls):
-        if ConfigCookiesSource.browser == "firefox":
-            cls.cookies = browser_cookie3.firefox()
-        if ConfigCookiesSource.browser == "chrome":
-            cls.cookies = browser_cookie3.chrome()
+def get_cookies():
+    if ConfigCookiesSource.browser == "firefox":
+        return browser_cookie3.firefox()
+    if ConfigCookiesSource.browser == "chrome":
+        return browser_cookie3.chrome()
+    raise ValueError(f"unsupported browser [{ConfigCookiesSource.browser}")
 
 
 class ConfigSiteId(Config):
