@@ -13,7 +13,7 @@ import requests
 from pornhub_api import PornhubApi
 
 import pyscrapers.core.utils
-from pyscrapers.configs import ConfigPornhubSearch, ConfigDebugRequests, ConfigCookiesSource, ConfigUrl
+from pyscrapers.configs import ConfigPornhubSearch, ConfigDebugRequests, ConfigUrl, get_cookies
 from pyscrapers.core.url_set import UrlSet
 from pyscrapers.workers.youtube_dl_handlers import youtube_dl_download_url, youtube_dl_download_urls
 
@@ -73,8 +73,7 @@ def download_search() -> None:
             code = e.args[0]["code"]
             if code == "2001":  # no videos found (end of results)
                 break
-            else:
-                raise e
+            raise e
         urls = [video.url for video in data.videos]
         if limit is not None:
             urls = list(islice(urls, 0, limit - counter))
@@ -123,27 +122,35 @@ def get_urls_from_page(root) -> List[str]:
     # video_section = video_sections[0]
     # <ul class="dropdownHottestVideos videos" id="hottestMenuSection">
     # <ul class="videos row-5-thumbs" id="mostRecentVideosSection">
-    xpath_attempts = [
+    # pyscrapers.core.utils.print_element(root)
+    # import sys
+    # sys.exit(1)
+    xpath_picks = [
         '//ul[contains(@class,\'pornstarsVideos\')]',
         '//ul[@id=\'moreData\']',
         '//ul[@id=\'mostRecentVideosSection\']',
+        #'//ul[@id=\'hottestMenuSection\']',
+        #'//ul[@id=\'recommMenuSection\']',
+        '//ul[@id=\'showAllChanelVideos\']',
     ]
     video_sections = []
-    for xpath_attempt in xpath_attempts:
-        video_sections = root.xpath(xpath_attempt)
-        if len(video_sections) == 1:
-            break
-    if len(video_sections) == 1:
-        video_section = video_sections[0]
+    for xpath_pick in xpath_picks:
+        candidates = root.xpath(xpath_pick)
+        if len(candidates) != 1:
+            continue
+        candidate = candidates[0]
+        video_sections.append(candidate)
+    urls = []
+    print(video_sections)
+    for video_section in video_sections:
         elements = video_section.xpath('li[contains(@class,\'pcVideoListItem\')]')
-        urls = []
         for element in elements:
-            key = element.attrib['_vkey']
+            # pyscrapers.core.utils.print_element(element)
+            # key = element.attrib['_vkey']
+            key = element.attrib['data-video-vkey']
             url = "https://www.pornhub.com/view_video.php?viewkey={key}".format(key=key)
             urls.append(url)
-        return urls
-    else:
-        return []
+    return urls
 
 
 def url_generator(url: str):
@@ -157,9 +164,8 @@ def url_generator(url: str):
 def download_url() -> None:
     if ConfigDebugRequests.debug:
         pyscrapers.core.utils.debug_requests()
-    ConfigCookiesSource.config_cookies()
     session = requests.Session()
-    session.cookies = ConfigCookiesSource.cookies
+    session.cookies = get_cookies()
     logger = logging.getLogger(__name__)
     urls = UrlSet()
     for url in url_generator(url=ConfigUrl.url):
